@@ -23,6 +23,7 @@ from pubtools.pulplib import (
     FileUnit,
     MaintenanceReport,
 )
+from pubtools.pulplib._impl.client.client import UploadResult
 from pubtools.pulplib._impl.client.search import search_for_criteria
 from .. import compat_attr as attr
 
@@ -450,7 +451,9 @@ class FakeClient(object):  # pylint:disable = too-many-instance-attributes
 
         return f_proxy(f_return(self._type_ids))
 
-    def _do_upload_file(self, upload_id, file_obj):
+    def _do_upload_file(
+        self, upload_id, file_obj, name="<unknown file>"
+    ):  # pylint: disable=unused-argument
         # We keep track of uploaded content as we may need it at import time.
         buffer = six.BytesIO()
         self._uploads_pending[upload_id] = buffer
@@ -460,15 +463,17 @@ class FakeClient(object):  # pylint:disable = too-many-instance-attributes
             file_obj = open(file_obj, "rb")
 
         def do_next_upload(checksum, size):
-            data = file_obj.read(1024 * 1024)
-            if data:
+            while True:
+                data = file_obj.read(1024 * 1024)
+                if not data:
+                    break
                 if isinstance(data, six.text_type):
                     data = data.encode("utf-8")
                 buffer.write(data)
                 checksum.update(data)
                 size += len(data)
-                return do_next_upload(checksum, size)
-            return f_return((checksum.hexdigest(), size))
+
+            return f_return(UploadResult(checksum.hexdigest(), size))
 
         out = f_flat_map(f_return(), lambda _: do_next_upload(hashlib.sha256(), 0))
 
@@ -515,7 +520,7 @@ class FakeClient(object):  # pylint:disable = too-many-instance-attributes
 
         return f_return([task])
 
-    def _request_upload(self):
+    def _request_upload(self, name):  # pylint: disable=unused-argument
         upload_request = {
             "_href": "/pulp/api/v2/content/uploads/%s/" % self._next_request_id(),
             "upload_id": "%s" % self._next_request_id(),
